struct InnerLeader<D: SharedUnlockDriver> {
driver: D,
follower_sessions: FollowerSessions,
ipc_client: Arc<dyn IpcClient>,
}Expand description
Inner implementation of the shared unlock leader, containing the actual state and logic. The
outer Leader struct is a thin wrapper around an Arc to allow for shared ownership across
async tasks.
Fields
driver: Dfollower_sessions: FollowerSessionsipc_client: Arc<dyn IpcClient>Auto Trait Implementations
impl<D> !Freeze for InnerLeader<D>
impl<D> !RefUnwindSafe for InnerLeader<D>
impl<D> Send for InnerLeader<D>where
D: Send,
impl<D> Sync for InnerLeader<D>where
D: Sync,
impl<D> Unpin for InnerLeader<D>where
D: Unpin,
impl<D> UnsafeUnpin for InnerLeader<D>where
D: UnsafeUnpin,
impl<D> !UnwindSafe for InnerLeader<D>